pub struct UserInOutPtr<T> { /* private fields */ }Expand description
A wrapper around a mutable pointer to user memory (read-write).
Implementations
Sourceimpl<T> UserInOutPtr<T>
impl<T> UserInOutPtr<T>
Sourcepub fn byte_offset(&self, count: isize) -> Self
pub fn byte_offset(&self, count: isize) -> Self
Returns a pointer offset by count bytes.
Sourcepub fn element_offset(&self, index: usize) -> Self
pub fn element_offset(&self, index: usize) -> Self
Returns a pointer offset by index elements.
Sourcepub fn reinterpret<U>(&self) -> UserInOutPtr<U>
pub fn reinterpret<U>(&self) -> UserInOutPtr<U>
Reinterprets the pointer as a pointer to type U.
Sourcepub const fn as_in_ptr(&self) -> UserInPtr<T>
pub const fn as_in_ptr(&self) -> UserInPtr<T>
Returns a UserInPtr viewing the same user memory.
Sourcepub const fn as_out_ptr(&self) -> UserOutPtr<T>
pub const fn as_out_ptr(&self) -> UserOutPtr<T>
Returns a UserOutPtr viewing the same user memory.
Sourcepub fn copy_from_user<'a>(
&self,
dst: &'a mut MaybeUninit<T>,
) -> Result<&'a mut T, Status>
pub fn copy_from_user<'a>( &self, dst: &'a mut MaybeUninit<T>, ) -> Result<&'a mut T, Status>
Copies a single element from userspace into dst.
Sourcepub fn read(&self) -> Result<T, Status>
pub fn read(&self) -> Result<T, Status>
Reads and returns a single copyable element from userspace.
Sourcepub fn copy_slice_from_user<'a>(
&self,
dst: &'a mut [MaybeUninit<T>],
) -> Result<&'a mut [T], Status>
pub fn copy_slice_from_user<'a>( &self, dst: &'a mut [MaybeUninit<T>], ) -> Result<&'a mut [T], Status>
Copies a slice of elements from userspace into dst.
Sourcepub fn copy_to_user(&self, src: &T) -> Result<(), Status>
pub fn copy_to_user(&self, src: &T) -> Result<(), Status>
Copies a single element from src to userspace.
Sourcepub fn copy_slice_to_user(&self, src: &[T]) -> Result<(), Status>
pub fn copy_slice_to_user(&self, src: &[T]) -> Result<(), Status>
Copies a slice of elements from src to userspace.