UserInPtr

Struct UserInPtr 

pub struct UserInPtr<T> { /* private fields */ }
A wrapper around a const pointer to user memory.

Implementations

Source

impl<T> UserInPtr<T>

pub const fn new(ptr: *const T) -> Self

Constructs a new UserInPtr.

pub fn is_null(&self) -> bool

Returns true if the underlying pointer is null.

pub fn as_ptr(&self) -> *const T

Returns the underlying raw pointer.

pub fn byte_offset(&self, count: isize) -> Self

Returns a pointer offset by count bytes.

pub fn element_offset(&self, index: usize) -> Self

Returns a pointer offset by index elements.

pub fn reinterpret<U>(&self) -> UserInPtr<U>

Reinterprets the pointer as a pointer to type U.

pub fn copy_from_user<'a>( &self, dst: &'a mut MaybeUninit<T>, ) -> Result<&'a mut T, Status>
where T: FromBytes + IntoBytes,

Copies a single element from userspace into dst.

pub fn read(&self) -> Result<T, Status>

Reads and returns a single copyable element from userspace.

pub fn copy_slice_from_user<'a>( &self, dst: &'a mut [MaybeUninit<T>], ) -> Result<&'a mut [T], Status>
where T: FromBytes + IntoBytes,

Copies a slice of elements from userspace into dst.