UserOutPtr

Struct UserOutPtr 

pub struct UserOutPtr<T> { /* private fields */ }
A wrapper around a mutable pointer to user memory (write-only).

Implementations

Source

impl<T> UserOutPtr<T>

pub const fn new(ptr: *mut T) -> Self

Constructs a new UserOutPtr.

pub fn is_null(&self) -> bool

Returns true if the underlying pointer is null.

pub fn as_ptr(&self) -> *mut T

Returns the underlying raw pointer.

pub fn byte_offset(&self, count: isize) -> Self

Returns a pointer offset by count bytes.

pub fn element_offset(&self, index: usize) -> Self

Returns a pointer offset by index elements.

pub fn reinterpret<U>(&self) -> UserOutPtr<U>

Reinterprets the pointer as a pointer to type U.

pub fn copy_to_user(&self, src: &T) -> Result<(), Status>
where T: IntoBytes + Immutable,

Copies a single element from src to userspace.

pub fn write(&self, val: T) -> Result<(), Status>
where T: IntoBytes + Immutable,

Writes a single copyable value to userspace.

pub fn copy_slice_to_user(&self, src: &[T]) -> Result<(), Status>
where T: IntoBytes + Immutable,

Copies a slice of elements from src to userspace.