pub struct UserInPtr<T> { /* private fields */ }Expand description
A wrapper around a const pointer to user memory.
Implementations
Sourceimpl<T> UserInPtr<T>
impl<T> UserInPtr<T>
Sourcepub fn byte_offset(&self, count: isize) -> Self
pub fn byte_offset(&self, count: isize) -> Self
Returns a pointer offset by count bytes.
Sourcepub fn element_offset(&self, index: usize) -> Self
pub fn element_offset(&self, index: usize) -> Self
Returns a pointer offset by index elements.
Sourcepub fn reinterpret<U>(&self) -> UserInPtr<U>
pub fn reinterpret<U>(&self) -> UserInPtr<U>
Reinterprets the pointer as a pointer to type U.
Sourcepub fn copy_from_user<'a>(
&self,
dst: &'a mut MaybeUninit<T>,
) -> Result<&'a mut T, Status>
pub fn copy_from_user<'a>( &self, dst: &'a mut MaybeUninit<T>, ) -> Result<&'a mut T, Status>
Copies a single element from userspace into dst.
Sourcepub fn read(&self) -> Result<T, Status>
pub fn read(&self) -> Result<T, Status>
Reads and returns a single copyable element from userspace.
Sourcepub fn copy_slice_from_user<'a>(
&self,
dst: &'a mut [MaybeUninit<T>],
) -> Result<&'a mut [T], Status>
pub fn copy_slice_from_user<'a>( &self, dst: &'a mut [MaybeUninit<T>], ) -> Result<&'a mut [T], Status>
Copies a slice of elements from userspace into dst.