pub struct UserOutPtr<T> { /* private fields */ }Expand description
A wrapper around a mutable pointer to user memory (write-only).
Implementations
Sourceimpl<T> UserOutPtr<T>
impl<T> UserOutPtr<T>
Sourcepub fn byte_offset(&self, count: isize) -> Self
pub fn byte_offset(&self, count: isize) -> Self
Returns a pointer offset by count bytes.
Sourcepub fn element_offset(&self, index: usize) -> Self
pub fn element_offset(&self, index: usize) -> Self
Returns a pointer offset by index elements.
Sourcepub fn reinterpret<U>(&self) -> UserOutPtr<U>
pub fn reinterpret<U>(&self) -> UserOutPtr<U>
Reinterprets the pointer as a pointer to type U.
Sourcepub fn copy_to_user(&self, src: &T) -> Result<(), Status>
pub fn copy_to_user(&self, src: &T) -> Result<(), Status>
Copies a single element from src to userspace.
Sourcepub fn copy_slice_to_user(&self, src: &[T]) -> Result<(), Status>
pub fn copy_slice_to_user(&self, src: &[T]) -> Result<(), Status>
Copies a slice of elements from src to userspace.